Page 135 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 135

Home

    One American who became an eye witness to Castro's
    tyranny was Anthony Bryant, once a black revolutionary,
    who while in a Cuban prison discovered the truth about
    Communism, and at the same time discovered God.

    Bryant made national headlines when, in 1969, he
    hijacked a passenger jetliner and diverted it from Miami
    to Havana. His objective was to obtain arms to be
    smuggled back to the United States to be used to initiate
    guerrilla warfare here. Once in Cuba, however, Bryant
    was arrested and charged with sedition against the Cuban

    Government. He was sentenced to 12 years in prison, not
    because he hijacked a jetliner or robbed the passengers
    on board, but because one of the men he robbed was a

    secret Cuban agent working in the United States. The
    agent had to go underground because of his exposure.

    After spending 12 years in Cuban prisons, Bryant was
    among several prisoners allowed to return to the United
    States during a public relations campaign put on by
    Castro. Bryant then traveled all over the United States
    telling of his experience in Castro's Marxist Utopia. Here
    are some of his eyewitness accounts:

    First of all, I'll tell you that I expected to find a
    government which would be caring, kind, and really
    considerate of its population. However, I found that it
    was really the exact opposite. I witnessed beatings there,
    I think I probably witnessed thousands in the 12 years I
    was in Cuba. It was a situation where it was a daily

    130

    The Secret Side of History

    member Dwight D. Eisenhower. The tragic results of

    their actions, and inactions, are now history.